// self
#include "radiofilteroptions.h"

// Qt
#include <QHash>

RadioFilterOptions::RadioFilterOptions(const std::vector<unity::dash::FilterOption::Ptr>& list,
                                       sigc::signal<void, unity::dash::FilterOption::Ptr> itemAddedSignal,
                                       sigc::signal<void, unity::dash::FilterOption::Ptr> itemRemovedSignal,
                                       QObject *parent) :
ListModelWrapper(parent)
, m_activeIndex(0)
{
    QHash<int, QByteArray> roles;
    roles[RadioFilterOptions::RoleItem] = "item";
    setRoleNames(roles);

    for (unsigned int i=0; i<list.size(); i++) {
        addItem(list[i], i);
    }
    itemAddedSignal.connect(sigc::mem_fun(this, &RadioFilterOptions::onItemAdded));
    itemRemovedSignal.connect(sigc::mem_fun(this, &RadioFilterOptions::onItemRemoved));
}

int RadioFilterOptions::activeIndex() const
{
    return m_activeIndex;
}

void RadioFilterOptions::addItem(unity::dash::FilterOption::Ptr item, int index)
{
    FilterOptions::addItem(item, index);
    connect(m_list[index], SIGNAL(activeChanged(bool)), this, SLOT(onActiveChanged(bool)));
    if (m_list[index]->active()) {
        m_activeIndex = index;
        Q_EMIT(activeIndexChanged());
    }
}

void RadioFilterOptions::removeItem(unity::dash::FilterOption::Ptr item, int index)
{
    disconnect(m_list[index], SIGNAL(activeChanged(bool)), this, SLOT(onActiveChanged(bool)));
    FilterOptions::removeItem(item, index);
}

void RadioFilterOptions::onActiveChanged(bool active)
{
    if (active) {
        int index = m_list.indexOf(static_cast<FilterOption*> (QObject::sender()));
        if (m_activeIndex != index) {
            m_activeIndex = index;
            Q_EMIT(activeIndexChanged());
        }
    }
}

#include "radiofilteroptions.moc"
